CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
97 lines
2.7 KiB
C++
97 lines
2.7 KiB
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
#include <resource_guards.hh>
|
|
|
|
/**
|
|
* @addtogroup hipKernelNameRefByPtr hipKernelNameRefByPtr
|
|
* @{
|
|
* @ingroup CallbackTest
|
|
* `hipKernelNameRefByPtr(const void* hostFunction, hipStream_t stream)` -
|
|
* returns the name of passed function pointer on desired stream
|
|
*/
|
|
|
|
__global__ void test_kernel() { return; }
|
|
|
|
/**
|
|
* Test Description
|
|
* ------------------------
|
|
* - Creates new stream and a function pointer
|
|
* - Verifies that valid API name is returned
|
|
* Test source
|
|
* ------------------------
|
|
* - unit/callback/hipKernelNameRefByPtr.cc
|
|
* Test requirements
|
|
* ------------------------
|
|
* - HIP_VERSION >= 5.2
|
|
* - Platform specific (AMD)
|
|
*/
|
|
HIP_TEST_CASE(Unit_hipKernelNameRefByPtr_Positive_Basic) {
|
|
const void* kernel_ptr{reinterpret_cast<const void*>(&test_kernel)};
|
|
StreamGuard stream_guard{Streams::created};
|
|
|
|
const char* kernel_name{hipKernelNameRefByPtr(kernel_ptr, stream_guard.stream())};
|
|
REQUIRE(kernel_name != nullptr);
|
|
REQUIRE(std::strlen(kernel_name) > 0);
|
|
}
|
|
|
|
/**
|
|
* Test Description
|
|
* ------------------------
|
|
* - Passes `nullptr` stream while function pointer is valid
|
|
* - Verifies that the returned value is not `nullptr`
|
|
* Test source
|
|
* ------------------------
|
|
* - unit/callback/hipKernelNameRefByPtr.cc
|
|
* Test requirements
|
|
* ------------------------
|
|
* - HIP_VERSION >= 5.2
|
|
* - Platform specific (AMD)
|
|
*/
|
|
HIP_TEST_CASE(Unit_hipKernelNameRefByPtr_Positive_StreamNullptr) {
|
|
const void* kernel_ptr{reinterpret_cast<const void*>(&test_kernel)};
|
|
StreamGuard stream_guard{Streams::nullstream};
|
|
|
|
const char* kernel_name{hipKernelNameRefByPtr(kernel_ptr, stream_guard.stream())};
|
|
REQUIRE(kernel_name != nullptr);
|
|
REQUIRE(std::strlen(kernel_name) > 0);
|
|
}
|
|
|
|
/**
|
|
* Test Description
|
|
* ------------------------
|
|
* - Performs validation when the function pointer is `nullptr`
|
|
* -# When stream is `nullptr`
|
|
* - Expected output: return `nullptr`
|
|
* -# When stream is valid
|
|
* - Expected output: return `nullptr`
|
|
* Test source
|
|
* ------------------------
|
|
* - unit/callback/hipKernelNameRefByPtr.cc
|
|
* Test requirements
|
|
* ------------------------
|
|
* - HIP_VERSION >= 5.2
|
|
* - Platform specific (AMD)
|
|
*/
|
|
HIP_TEST_CASE(Unit_hipKernelNameRefByPtr_Negative_KernelNullptr) {
|
|
const void* kernel_ptr{nullptr};
|
|
|
|
SECTION("stream is nullptr") {
|
|
StreamGuard stream_guard{Streams::nullstream};
|
|
REQUIRE(hipKernelNameRefByPtr(kernel_ptr, stream_guard.stream()) == nullptr);
|
|
}
|
|
|
|
SECTION("stream is created") {
|
|
StreamGuard stream_guard{Streams::created};
|
|
REQUIRE(hipKernelNameRefByPtr(kernel_ptr, stream_guard.stream()) == nullptr);
|
|
}
|
|
}
|
|
|
|
/**
|
|
* End doxygen group CallbackTest.
|
|
* @}
|
|
*/
|